scipy.sparse.dia_matrix
=======================

.. currentmodule:: scipy.sparse

.. autoclass:: dia_matrix

   

   .. HACK
      .. autosummary::
         :toctree:
      
         dia_matrix.__init__
         dia_matrix.asformat
         dia_matrix.asfptype
         dia_matrix.astype
         dia_matrix.conj
         dia_matrix.conjugate
         dia_matrix.copy
         dia_matrix.diagonal
         dia_matrix.dot
         dia_matrix.getH
         dia_matrix.get_shape
         dia_matrix.getcol
         dia_matrix.getformat
         dia_matrix.getmaxprint
         dia_matrix.getnnz
         dia_matrix.getrow
         dia_matrix.mean
         dia_matrix.multiply
         dia_matrix.nonzero
         dia_matrix.reshape
         dia_matrix.set_shape
         dia_matrix.setdiag
         dia_matrix.sum
         dia_matrix.toarray
         dia_matrix.tobsr
         dia_matrix.tocoo
         dia_matrix.tocsc
         dia_matrix.tocsr
         dia_matrix.todense
         dia_matrix.todia
         dia_matrix.todok
         dia_matrix.tolil
         dia_matrix.transpose



   

   .. HACK
      .. autosummary::
         :toctree:
      
         dia_matrix.dtype
         dia_matrix.nnz
         dia_matrix.shape

